@@ -93,9 +93,8 @@ grouped_ggbetweenstats <- function(data,
 
   # creating a dataframe
   df <-
-    data %>%
     dplyr::select(
-      .data = .,
+      .data = data,
       {{ grouping.var }},
       {{ x }},
       {{ y }},
@@ -107,7 +106,7 @@ grouped_ggbetweenstats <- function(data,
 
   plotlist_purrr <-
     purrr::pmap(
-      .l = list(data = df, title = paste(title.prefix, ": ", names(df), sep = "")),
+      .l = list(data = df, title = paste0(title.prefix, ": ", names(df))),
       .f = ggstatsplot::ggbetweenstats,
       # put common parameters here
       x = {{ x }},
